==> dde-network-core_1.0.64.orig.tar.xz: dde-network-core-1.0.64/dock-network-plugin/translations/dock-network-plugin_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ro" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Reţea</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tip Securitate</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandă</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfață</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mască de rețea</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primar</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Viteză</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispozitiv Dezactivat</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectat dar fară acces Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neconectat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cablu Reţea Deconectat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectare</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificare</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obţinere Adresă IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectat</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Deconectat</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Eșuat</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rețea conectată</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rețea Cablu %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rețea fără fir</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rețea fără fir %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispozitiv Dezactivat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cablu Reţea Deconectat</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neconectat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectare</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectat dar fară acces Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Dezactivați conexiunea prin cablu</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activați conexiunea prin cablu</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Dezactivați conexiunea fără fir</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activați conexiunea fără fir</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Dezactivați conexiunea la rețea</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activați rețeaua</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configurări de rețea</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.4.orig.tar.xz: dde-network-core-1.1.4/dock-network-plugin/translations/dock-network-plugin_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ro">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rețea fără fir</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rețea conectată</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Reţea</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectare la rețele ascunse</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Parola</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anulează</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Conectare</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protocol</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Tip Securitate</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Canal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandă</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Interfață</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Mască de rețea</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Portalul</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS primar</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Viteză</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispozitiv Dezactivat</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectat dar fară acces Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neconectat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cablu Reţea Deconectat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectare</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificare</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Obţinere Adresă IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Conectat</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Deconectat</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Eșuat</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rețea conectată</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rețea Cablu %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rețea fără fir</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rețea fără fir %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Dispozitiv Dezactivat</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cablu Reţea Deconectat</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neconectat</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Conectare</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Conectat dar fară acces Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Dezactivați conexiunea prin cablu</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Activați conexiunea prin cablu</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Dezactivați conexiunea fără fir</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Activați conexiunea fără fir</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Dezactivați conexiunea la rețea</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Activați rețeaua</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Configurări de rețea</translation>
    </message>
</context>
</TS>
